## Some coding tests
- black (pyproject.toml)
- isort (pyproject.toml, isort.cfg)
- flake8
- pytest (setup.cfg)
- pytest-cov (setup.cfg)
- mypy (mypy.ini)
- Other Configuration files: tox.ini, .editorconfig

### References
1. https://pycqa.github.io/isort/docs/configuration/config_files.html
2. https://stackoverflow.com/questions/14399534/reference-requirements-txt-for-the-install-requires-kwarg-in-setuptools-setup-py
3. https://ianhopkinson.org.uk/2022/02/understanding-setup-py-setup-cfg-and-pyproject-toml-in-python/
4. https://towardsdatascience.com/pre-commit-hooks-you-must-know-ff247f5feb7e
5. https://mypy.readthedocs.io/en/stable/running_mypy.html
6. https://mypy.readthedocs.io/en/stable/config_file.html#config-file
7. https://pre-commit.com/
